using Microsoft.VisualStudio.TestTools.UnitTesting;
using SSIS.Test;
using SSIS.Test.Metadata;
using System.IO;

namespace MySsisUnitTests.LiveTests
{
    [ActionClass("CUSTOMERS", "CopyCustomers.dtsx")]
    public class CopyCustomers : BaseLiveTest
    {
        public CopyCustomers()
            : base()
        {
            // reset the environment to allow this to be runnable
            if (File.Exists(Constants.CustomersFileDestination))
                File.Delete(Constants.CustomersFileDestination);

            if (File.Exists(Constants.CustomersFileConverted))
                File.Delete(Constants.CustomersFileConverted);
        }

        [ActionMethod(@"\[CopyCustomers]")]
        public void TestWholePackage(ActionContext context)
        {
            // check if the package executed successfully
            Assert.AreEqual(true, context.Package.IsExecutionSuccess);
        }

        [ActionMethod(@"\[CopyCustomers]\[FST Copy Source File]")]
        public void TestCopySourceFile(ActionContext context)
        {
            // check if the task "FST Copy Source File" executed successfully and if the file has been copied
            Assert.AreEqual(true, context.ActiveExecutable.IsExecutionSuccess);
            Assert.AreEqual(true, File.Exists(Constants.CustomersFileDestination));
        }

        [ActionMethod(@"\[CopyCustomers]\[DFT Convert customer names]")]
        public void TestConvertCustomerNames(ActionContext context)
        {
            // check if the task "DFT Convert customer names" executed successfully and if the names have been upper cased
            Assert.AreEqual(true, context.ActiveExecutable.IsExecutionSuccess);            
            string[] lines = File.ReadAllLines(Constants.CustomersFileConverted);
            Assert.AreEqual("COMPANY2", lines[2].Split(',')[1]);
        }
    }
}
