using Microsoft.VisualStudio.TestTools.UnitTesting;
using SSIS.Test;
using SSIS.Test.Dts;
using SSIS.Test.Metadata;

namespace MySsisUnitTests.LiveTests
{
     [ActionClass("CUSTOMERS", "LoadCustomers.dtsx")]
    public class LoadCustomers : BaseLiveTest
    {
        [ActionMethod(@"\[LoadCustomers]")]
        public void TestWholePackage(ActionContext context)
        {
            // check if the package executed successfully
            Assert.AreEqual(true, context.Package.IsExecutionSuccess);

            // check package variable - it should equals 3 since we have 3 customers in the input file
            DtsVariable variable = context.Package.GetVariableForPath(@"\[LoadCustomers].[CustomerCount]");
            int countInsert = (int)variable.GetValue();

            Assert.AreEqual(3, countInsert);
        }

        [ActionMethod(@"\[LoadCustomers]\[SEQC Load]\[DFT Load customers]")]
        public void TestLoadCustomers(ActionContext context)
        {
            // check if the task "DFT Load customers" executed successfully
            Assert.AreEqual(true, context.ActiveExecutable.IsExecutionSuccess);

            // check the target table - it should contain 3 customers from the input file
            context.DataAccess.OpenConnection(Constants.DbConnectionString);
            int rowCount = (int)context.DataAccess.ExecuteScalar(@"select count(*) from [dbo].[CustomersStaging]");
            context.DataAccess.CloseConnection();

            Assert.AreEqual(3, rowCount);
        }

        [ActionMethod(@"\[LoadCustomers]\[SEQC Load]\[SQL Truncate CustomersStaging]")]
        public void TestTruncateCustomerStaging(ActionContext context)
        {
            // check if the task "SQL Truncate CustomersStaging" executed successfully
            Assert.AreEqual(true, context.ActiveExecutable.IsExecutionSuccess);

            // check the target table - it should contain no data after truncate
            context.DataAccess.OpenConnection(Constants.DbConnectionString);
            int rowCount = (int)context.DataAccess.ExecuteScalar(@"select count(*) from [dbo].[CustomersStaging]");
            context.DataAccess.CloseConnection();

            Assert.AreEqual(0, rowCount);
        }
    }
}
