using SSIS.Test;
using SSIS.Test.Report;
using System;

namespace MySsisUnitTests
{
    class Program
    {
        [STAThread]
        static void Main(string[] args)
        {
            RunUnitTests();
            // to run live tests, comment the RunUnitTests and uncomment the RunLiveTests
            //RunLiveTests();

            if (System.Diagnostics.Debugger.IsAttached)
                System.Diagnostics.Debugger.Break();
        }

        /// <summary>
        /// Executes demo unit tests.
        /// </summary>
        private static void RunUnitTests()
        {
            // create engine for unit testing
            IUnitTestEngine engine = EngineFactory.GetClassInstance<IUnitTestEngine>();

            // load packages and relate them to the logical group - repository
            engine.LoadPackages("CUSTOMERS", Constants.PathToPackages);

            // load unit tests from the current assembly
            engine.LoadRepositoryUnitTests("CUSTOMERS");

            // execute unit tests
            engine.ExecuteUnitTestsWithGui();
        }

        /// <summary>
        /// Executes demo live tests.
        /// </summary>
        private static void RunLiveTests()
        {
            // set package execution parameters eg. variables, connections
            var parameters = new ExecutionParameters();

            // add variables and their values to be set when the package has been loaded
            parameters.AddVariable(@"\[Main].[ConnectionString]", Constants.SsisDbConnectionString);
            parameters.AddVariable(@"\[Main].[CopyCustomersPath]", Constants.PathToCopyCustomersPackage);
            parameters.AddVariable(@"\[Main].[LoadCustomersPath]", Constants.PathToLoadCustomersPackage);
            parameters.AddVariable(@"\[Main].[ConvertDestinationPath]", Constants.CustomersFileConverted);
            parameters.AddVariable(@"\[Main].[DestinationPath]", Constants.CustomersFileDestination);
            parameters.AddVariable(@"\[Main].[SourcePath]", Constants.CustomersFileSource);

            // create engine for live testing
            ILiveTestEngine engine = EngineFactory.GetClassInstance<ILiveTestEngine>();

            // load packages and relate them to the logical group - repository
            engine.LoadPackages("CUSTOMERS", Constants.PathToPackages);

            // load live tests from the current assembly
            engine.LoadRepositoryActions("CUSTOMERS");

            // set execution parameters
            engine.SetExecutionParameters(parameters);

            // execute the package and attach live tests
            engine.ExecuteLiveTestsWithGui("CUSTOMERS", "Main.dtsx");
        }
    }
}
