using Microsoft.VisualStudio.TestTools.UnitTesting;
using SSIS.Test;
using SSIS.Test.Dts;
using SSIS.Test.Metadata;
using System.IO;

namespace MySsisUnitTests.UnitTests
{
    [UnitTest("CUSTOMERS", "CopyCustomers.dtsx")]
    public class CopyCustomersTest : BaseUnitTest
    {
        protected override void Setup(SetupContext context)
        {
            // clean up previous executions
            if (File.Exists(Constants.CustomersFileDestination))
                File.Delete(Constants.CustomersFileDestination);

            if (File.Exists(Constants.CustomersFileConverted))
                File.Delete(Constants.CustomersFileConverted);
            
            // set package variables to the correct paths
            DtsVariable sourceFile = context.Package.GetVariable(@"SourcePath");
            sourceFile.SetValue(Constants.CustomersFileSource);

            DtsVariable destinationFile = context.Package.GetVariable(@"DestinationPath");
            destinationFile.SetValue(Constants.CustomersFileDestination);

            DtsVariable convertedFile = context.Package.GetVariable(@"ConvertDestinationPath");
            convertedFile.SetValue(Constants.CustomersFileConverted);
        }

        protected override void Verify(VerificationContext context)
        {
            // check if package executed and if all files are copied
            Assert.AreEqual(true, context.Package.IsExecutionSuccess);
            Assert.AreEqual(true, File.Exists(Constants.CustomersFileDestination));
            Assert.AreEqual(true, File.Exists(Constants.CustomersFileConverted));
            string[] lines = File.ReadAllLines(Constants.CustomersFileConverted);
            Assert.AreEqual("COMPANY2", lines[2].Split(',')[1]);
        }

        protected override void Teardown(TeardownContext context)
        {
            // delete all files that were used for this unit test
            File.Delete(Constants.CustomersFileDestination);
            File.Delete(Constants.CustomersFileConverted);
        }
    }
}
