using Microsoft.VisualStudio.TestTools.UnitTesting;
using SSIS.Test;
using SSIS.Test.Dts;
using SSIS.Test.Metadata;
using System.IO;

namespace MySsisUnitTests.UnitTests
{
    [UnitTest("CUSTOMERS", "LoadCustomers.dtsx", ExecutableName = @"\[LoadCustomers]\[SEQC Load]\[DFT Load customers]")]
    class LoadCustomersTest : BaseUnitTest
    {
        protected override void Setup(SetupContext context)
        {
            // reset the environment to allow this to be runnable
            if (File.Exists(Constants.CustomersFileDestination))
                File.Delete(Constants.CustomersFileDestination);

            if (File.Exists(Constants.CustomersFileConverted))
                File.Delete(Constants.CustomersFileConverted);

            // copy the source file needed by the data flow
            File.Copy(Constants.CustomersFileSource, Constants.CustomersFileDestination);
            
            // truncate the target table
            context.DataAccess.OpenConnection(Constants.DbConnectionString);
            context.DataAccess.ExecuteNonQuery("truncate table [dbo].[CustomersStaging]");
            context.DataAccess.CloseConnection();

            // set connection strings
            DtsConnection conn = context.Package.GetConnection("CustomerDB");
            conn.SetConnectionString(Constants.SsisDbConnectionString);

            conn = context.Package.GetConnection("Customers Src");
            conn.SetConnectionString(Constants.CustomersFileDestination);
        }

        protected override void Verify(VerificationContext context)
        {
            // check if package and target task executed
            Assert.AreEqual(true, context.Package.IsExecutionSuccess);
            Assert.AreEqual(true, context.ActiveExecutable.IsExecutionSuccess);

            // check number of customers in the target table - it should be 3 since we have 3 in the source file
            context.DataAccess.OpenConnection(Constants.DbConnectionString);
            int rowCount = (int)context.DataAccess.ExecuteScalar(@"select count(*) from [dbo].[CustomersStaging]");
            context.DataAccess.CloseConnection();

            Assert.AreEqual(3, rowCount);
        }

        protected override void Teardown(TeardownContext context)
        {
            // clean up - delete all used files and truncate table
            File.Delete(Constants.CustomersFileDestination);
            context.DataAccess.OpenConnection(Constants.DbConnectionString);
            context.DataAccess.ExecuteNonQuery("truncate table [dbo].[CustomersStaging]");
            context.DataAccess.CloseConnection();
        }
    }
}
